'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports['default'] = run;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

var _browserify = require('browserify');

var _browserify2 = _interopRequireDefault(_browserify);

var _watchify = require('watchify');

var _watchify2 = _interopRequireDefault(_watchify);

var _errorify = require('errorify');

var _errorify2 = _interopRequireDefault(_errorify);

var _testem = require('testem');

var _testem2 = _interopRequireDefault(_testem);

var _concatStream = require('concat-stream');

var _concatStream2 = _interopRequireDefault(_concatStream);

var _testemLibServer = require('testem/lib/server');

var _testemLibServer2 = _interopRequireDefault(_testemLibServer);

/**
 * Run testem server with `opts`.
 *
 * @param {Object} opts
 */

var debug = (0, _debug2['default'])('browserify-test');

function run() {
  var _ref = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

  var files = _ref.files;
  var transform = _ref.transform;
  var watch = _ref.watch;

  if (!files || !files.length) throw new Error('specify files');
  if (!transform) transform = [];
  debug('opts = %o', { files: files, transform: transform, watch: watch });

  // setup testem & browserify

  var testem = new _testem2['default']();
  var config = {
    framework: 'mocha',
    launch_in_ci: ['phantomjs'],
    launch_in_dev: ['phantomjs']
  };

  var b = undefined;
  if (watch) {
    testem.startDev(config);
    b = (0, _watchify2['default'])((0, _browserify2['default'])(files, _watchify2['default'].args));
    b.on('update', function () {
      return testem.app.startTests();
    }); // reload
  } else {
      testem.startCI(config);
      b = (0, _browserify2['default'])(files);
    }

  b.plugin(_errorify2['default']);
  transform.forEach(b.transform, b);

  // monkey-patch testem to inject compiled bundle to root url

  _testemLibServer2['default'].prototype.serveHomePage = function (req, res) {
    debug('serve /');
    b.bundle().on('error', function (err) {
      res.status(500).send(err.stack);
    }).pipe((0, _concatStream2['default'])(function (buf) {
      res.status(200).send(template(buf));
    }));
  };
}

/**
 * Render default index.html with `buf` as a <script> content.
 *
 * @param {Buffer} buf
 * @return {String}
 */

function template(buf) {
  return '\n    <!doctype html>\n    <html>\n    <head>\n      <title>Tests</title>\n      <link rel="stylesheet" href="/testem/mocha.css">\n      <script src="/testem/mocha.js"></script>\n      <script src="/testem.js"></script>\n      <script>mocha.setup(\'bdd\')</script>\n    </head>\n    <body>\n      <div id="mocha"></div>\n      <script>' + buf.toString() + '</script>\n      <script>mocha.run()</script>\n    </body>\n    </html>\n  ';
}
module.exports = exports['default'];